@@ -165,6 +165,12 @@ class Accessory(object):
 
         self._set_services()
 
+    def __repr__(self):
+        """Return the representation of the accessory."""
+        services = [s.display_name for s in self.services]
+        return "<accessory display_name='{}' services={}>" \
+            .format(self.display_name, services)
+
     def __getstate__(self):
         state = self.__dict__.copy()
         state["broker"] = None
@@ -250,7 +256,7 @@ class Accessory(object):
         for s in servs:
             self.services.append(s)
             self.iid_manager.assign(s)
-            for c in s.characteristics + s.opt_characteristics:
+            for c in s.characteristics:
                 self.iid_manager.assign(c)
                 c.broker = self
 
@@ -333,9 +339,9 @@ class Accessory(object):
         print(self.qr_code.terminal(), flush=True)
 
     def get_characteristic(self, aid, iid):
-        """Get's the characteristic for the given IID.
+        """Get the characteristic for the given IID.
 
-        The AID isused to verify if the search is in the correct accessory.
+        The AID is used to verify if the search is in the correct accessory.
         """
         if aid != self.aid:
             return None
@@ -427,12 +433,6 @@ class Bridge(Accessory):
                                      setup_id=setup_id)
         self.accessories = {}  # aid: acc
 
-    def _set_services(self):
-        """Call the base method and add the BridgingState Service."""
-        super(Bridge, self)._set_services()
-        self.add_service(
-            get_serv_loader().get("BridgingState"))
-
     def set_sentinel(self, run_sentinel):
         """Set the same sentinel to all contained accessories."""
         super(Bridge, self).set_sentinel(run_sentinel)
@@ -461,8 +461,9 @@ class Bridge(Accessory):
             raise ValueError("Bridges cannot be bridged")
 
         if acc.aid is None:
+            # For some reason AID=7 gets unsupported. See issue #61
             acc.aid = next(aid for aid in itertools.count(2)
-                           if aid not in self.accessories)
+                           if aid != 7 and aid not in self.accessories)
         elif acc.aid == self.aid or acc.aid in self.accessories:
             raise ValueError("Duplicate AID found when attempting to add accessory")
 
