@@ -382,7 +382,7 @@ class AccessoryDriver(object):
             rep = {"aid": aid, "iid": iid}
             char = self.accessory.get_characteristic(aid, iid)
             try:
-                rep["value"] = char.get_value()
+                rep["value"] = char.value
                 rep["status"] = HAP_CONSTANTS.CHAR_STAT_OK
             except CharacteristicError:
                 logger.error("Error getting value for characteristic %s.", id)
@@ -440,7 +440,7 @@ class AccessoryDriver(object):
             }
             if "value" in cq:
                 # TODO: status needs to be based on success of set_value
-                char.set_value(cq["value"], should_notify=False)
+                char.set_value(cq["value"], should_notify=True)
                 if "r" in cq:
                     response["value"] = char.value
 
